@@ -383,7 +383,7 @@ Same as C<pp_bless> command. Specifies the package (i.e. class)
 to which your new I<pp_def>ed methods will be added. Defaults
 to C<PDL> if omitted.
 
-    use Inline Pdlpp => Config => BLESS => 'PDL::Complex';
+    use Inline Pdlpp => Config => BLESS => 'PDL::MyPackage';
 
 cf L</PACKAGE>, equivalent for L<PDL::PP/pp_addxs>.
 
@@ -503,7 +503,7 @@ to include an C<Inline-E<gt>init> call in your script, e.g.
 There is currently an undesired interaction between
 L<PDL::NiceSlice> and C<Inline::Pdlpp>.
 Since PP code generally contains expressions
-of the type C<$var()> (to access piddles, etc)
+of the type C<$var()> (to access ndarrays, etc)
 L<PDL::NiceSlice> recognizes those incorrectly as
 slice expressions and does its substitutions. For the moment
 (until hopefully the parser can deal with that) it is best to
